<?php
/*
Plugin Name: TravelDesk Transportation
Plugin URL: https://www.traveldesk.mx
Description: Plugin for TravelDesk companies who want to display their company's booking engine under their own Wordpress website.
Version: 1.0
Author: TravelDesk Company
Author URL: https://www.traveldesk.mx
License: GPL2
License URL: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: traveldesk
*/

// Encolar los scripts y estilos
function traveldesk_enqueue_scripts() {
    wp_enqueue_style('traveldesk-style', plugins_url('style.css', __FILE__));
    wp_enqueue_script('traveldesk-script', plugins_url('main.js', __FILE__), array('jquery'), null, true);
    wp_enqueue_script('google-maps', 'https://maps.googleapis.com/maps/api/js?key=AIzaSyDrzKuidxeCpZjuBjcfDqwTDHLYWcYertE&libraries=places', array(), null, true);

    // Encolar Font Awesome
    wp_enqueue_style('font-awesome', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.1/css/all.min.css', array(), '6.5.1');

    // Enqueue Stripe.js
    wp_enqueue_script('stripe-js', 'https://js.stripe.com/v3/', array(), null, true);


    // Pasar el valor del subdominio al archivo JS
    $subdomain = get_option('traveldesk_subdomain', ''); // 'traveldesk' es el valor por defecto
    // $api_url = 'http://localhost:8000/api/';  // Ruta global de la API
    $api_url = 'https://api.traveldesk.mx/api/';  // Ruta global de la API
    $is_localhost = strpos($api_url, 'localhost') !== false;

    wp_localize_script('traveldesk-script', 'traveldesk_data', array(
        'subdomain' => $subdomain,
        'api_url' => $api_url,
        'is_localhost' => $is_localhost
    ));
}
add_action('wp_enqueue_scripts', 'traveldesk_enqueue_scripts');

// Crear una página de configuración en el menú de administración
function traveldesk_create_menu() {
    add_menu_page(
        'TravelDesk Transportation',    // Título de la página
        'TravelDesk Transportation',    // Título del menú
        'manage_options',         // Capacidad del usuario
        'traveldesk-transportation-settings',    // Slug de la página
        'traveldesk_settings_page', // Función que muestra el contenido
        plugins_url('Main-TravelDesk.svg', __FILE__), // Ruta de la imagen del ícono
        110                        // Posición en el menú
    );
}
add_action('admin_menu', 'traveldesk_create_menu');

// Página de configuración del plugin
function traveldesk_settings_page() {
    ?>
    <div class="wrap">
        <h1 class="mb-4"><i class="fa fa-cogs"></i> TravelDesk Settings</h1>
        
        <div class="card">
            <div class="card-header bg-primary text-white">
                <h2 class="mb-0"><i class="fa fa-sliders-h"></i> General configuration</h2>
            </div>
            <div class="card-body">
                <form method="post" action="options.php">
                    <?php
                    settings_fields('traveldesk-settings-group');
                    do_settings_sections('traveldesk-settings-group');
                    ?>
                    <div class="mb-3">
                        <label for="traveldesk_subdomain" class="form-label"><i class="fa fa-globe"></i> Subdomain</label><br>
                        <input type="text" name="traveldesk_subdomain" id="traveldesk_subdomain" class="form-control" value="<?php echo esc_attr(get_option('traveldesk_subdomain')); ?>" placeholder="Ejemplo: miempresa">
                        <br>
                        <small class="form-text text-muted">
                        Enter the subdomain you use under traveldesk.mx. For example, if your subdomain is <strong>mycompanyname</strong>, the URL would be <strong>mycompanyname.traveldesk.mx</strong>.
                        </small>
                    </div>
                    
                    <button type="submit" class="btn btn-success btn-lg">
                        <i class="fa fa-save"></i> Save subdomain
                    </button>
                </form>
            </div>
        </div>

        <!-- Plugin Usage Card -->
        <div class="card mt-4">
            <div class="card-header bg-info text-white">
                <h2 class="mb-0"><i class="fa fa-book"></i> Plugin Usage</h2>
            </div>
            <div class="card-body">
                <p>
                    To display the TravelDesk booking engine on your website, please add the following shortcode to the page where you want it to appear:
                </p>
                <pre><code>[traveldesk_transportation]</code></pre>
                <p>
                    Simply copy and paste the shortcode into the content area of your desired page using the WordPress editor.
                </p>
            </div>
        </div>

        <!-- Sección Adicional: Información del Plugin -->
        <div class="card mt-4">
            <div class="card-header bg-secondary text-white">
                <h2 class="mb-0"><i class="fa fa-info-circle"></i> Plugin information</h2>
            </div>
            <div class="card-body">
                <p>
                <strong>TravelDesk Transportation</strong> is a plugin designed for businesses that want to integrate their booking engine directly into their WordPress website. With this plugin, you can manage transportation bookings efficiently and customized.
                </p>
                <p>
                    <strong>Version:</strong> 1.0<br>
                    <strong>Author:</strong> TravelDesk Company<br>
                    <strong>License:</strong> GPL2
                </p>
                <a href="https://www.traveldesk.mx" class="btn btn-primary" target="_blank">
                    <i class="fa fa-external-link-alt"></i> Visit website
                </a>
            </div>
        </div>
    </div>
    <?php
}

// Registrar la opción de subdominio
function traveldesk_register_settings() {
    register_setting('traveldesk-settings-group', 'traveldesk_subdomain');
}
add_action('admin_init', 'traveldesk_register_settings');

// Función del shortcode para mostrar el contenedor de la información
function traveldesk_transportation_shortcode() {
    return '
    <div id="traveldesk-booking" class="card pluginMainCard">
        <div class="card-body">

            <!-- Spinner -->
            <div id="loading-spinner" class="full-page-loader" style="display:none; background-color: #1c1c1c; position: fixed; top: 0; left: 0; width: 100%; height: 100%; z-index: 9999; display: flex; justify-content: center; align-items: center;">
                <div class="loading" style="text-align: center;">
                    <div class="spinner-border text-light" role="status"></div>
                    <p style="color: white; margin-top: 10px;">Loading...</p>
                </div>
            </div>

            <!-- Tabs Navigation -->
            <ul class="nav nav-tabs p-4 custom-tabs" id="bookingTabs" role="tablist">
                <!-- No mostrar "Destinations" en la numeración ni en el menú inicialmente -->
                <li class="nav-item" role="presentation" id="tab-destinations" style="display: none;">
                    <button class="nav-link disabled" id="destinations-tab" data-bs-toggle="tab" data-bs-target="#destinations" type="button" role="tab">
                        <span class="step-number">1</span> Choose your destination
                    </button>
                </li>
                <!-- El resto de las pestañas sin tener en cuenta Destinations -->
                <li class="nav-item" role="presentation">
                    <button class="nav-link active disabled" id="calendar-tab" data-bs-toggle="tab" data-bs-target="#calendar" type="button" role="tab">
                        <span class="step-number">2</span> Service and dates
                    </button>
                </li>
                <li class="nav-item" role="presentation">
                    <button class="nav-link disabled" id="vehicles-tab" data-bs-toggle="tab" data-bs-target="#vehicles" type="button" role="tab">
                        <span class="step-number">3</span> Vehicles
                    </button>
                </li>
                <li class="nav-item" role="presentation">
                    <button class="nav-link disabled" id="addons-tab" data-bs-toggle="tab" data-bs-target="#addons" type="button" role="tab">
                        <span class="step-number">4</span> Additional products
                    </button>
                </li>
                <li class="nav-item" role="presentation">
                    <button class="nav-link disabled" id="client-tab" data-bs-toggle="tab" data-bs-target="#client" type="button" role="tab">
                        <span class="step-number">5</span> Finish reservation
                    </button>
                </li>
            </ul>

            <!-- Tabs Content -->
            <div class="tab-content p-4" id="bookingTabsContent">
                <div class="tab-pane fade" id="destinations" role="tabpanel">
                    <div id="destinations-container" class="row"></div>
                </div>

                <!-- Paso de Calendario (Formulario) -->
                <div class="tab-pane fade show active" id="calendar" role="tabpanel">
                    
                    <div id="step-calendar" class="step-content">
                        <form id="calendar-form">
                            <div class="text-start mb-4">
                                <label for="serviceType" class="form-label">Service Type</label>
                                <br>
                                <input type="radio" class="btn-check" id="one-way" value="1" name="serviceType" autocomplete="off" checked>
                                <label class="btn btn-outline-primary radio-button" for="one-way">
                                    <i class="fa-solid fa-arrow-rotate-right"></i> One way
                                </label>

                                <input type="radio" class="btn-check" id="round-trip" value="2" name="serviceType" autocomplete="off">
                                <label class="btn btn-outline-primary radio-button mx-2" for="round-trip">
                                    <i class="fa-solid fa-arrows-rotate"></i> Round trip
                                </label>
                            </div>

                            <!-- Campo Origin y Destination con botón de intercambio -->
                            <div class="container" style="padding:0px">
                                <div class="row mb-4 align-items-end">
                                    <!-- Campo Origin -->
                                    <div class="col-md col-sm-12">
                                        <label for="origin" class="form-label">Origin</label>
                                        <input type="text" id="origin" class="form-control" placeholder="Enter origin">
                                    </div>

                                    <!-- Botón para intercambiar valores -->
                                    <div class="col-md-auto col-sm-12">
                                        <button type="button" class="btn btn-outline-primary switcher-button" onclick="swapValues()">
                                            <i class="fa fa-exchange-alt"></i>
                                        </button>
                                    </div>

                                    <!-- Campo Destination -->
                                    <div class="col-md col-sm-12">
                                        <label for="destination" class="form-label">Destination</label>
                                        <input type="text" id="destination" class="form-control" placeholder="Enter destination">
                                    </div>
                                </div>
                            </div>


                            <!-- Fechas y horarios dinámicos -->
                            <div id="loading-dynamic-fields" style="display: none; text-align: center; padding: 20px;">
                                <div class="loading" style="text-align: center;">
                                    <div class="spinner-border" role="status"></div>
                                    <p style="margin-top: 10px;">Loading fields...</p>
                                </div>
                            </div>
                            <div id="dynamic-fields-container">
                                <div id="dynamic-fields">
                                <!-- Fechas dinámicas según si es aeropuerto o no -->
                                </div>
                            </div>

                            <div class="container" style="padding:0px">
                                <div class="row mb-4 align-items-end">
                            
                                    <!-- Campo Adults -->
                                    <div class="col akc-input">
                                        <label for="adults" class="form-label">Adults</label>
                                        <input type="number" id="adults" class="form-control" min="1">
                                    </div>
                                    
                                    <!-- Campo Kids -->
                                    <div class="col akc-input">
                                        <label for="kids" class="form-label">Kids</label>
                                        <input type="number" id="kids" class="form-control" min="0">
                                    </div>
                                    
                                    <!-- Campo Infants -->
                                    <div class="col akc-input">
                                        <label for="infants" class="form-label">Infants</label>
                                        <input type="number" id="infants" class="form-control" min="0">
                                    </div>

                                </div>
                            </div>

                            <!-- Campo de "Sales Representative Code" y Botón "Next" -->
                            <hr width="100%" class="mt-5">
                            <div class="d-flex justify-content-between">
                                <div class="col-md-auto">
                                    <!-- Campo de texto para el código del representante -->
                                    <input type="text" id="repCode" class="form-control" placeholder="Sales representative code">
                                </div>

                                <div class="col-md-auto">
                                    <!-- Botón "Next" -->
                                    <button type="submit" class="btn btn-primary px-4 step-btn">
                                        Next
                                        <span id="next-spinner" style="display: none;" class="spinner-border spinner-border-sm mx-2" role="status" aria-hidden="true"></span>
                                        <i id="next-icon" class="fa-solid fa-chevron-right"></i>
                                    </button>
                                </div>
                            </div>
                        </form>

                        <div id="form-errors" class="alert alert-danger mt-3" style="display: none;"></div>

                    </div>
                </div>

                <div class="tab-pane fade" id="vehicles" role="tabpanel">
                    <!-- Spinner para la carga de vehículos -->
                    <div id="vehicles-loading-spinner" style="display: none; text-align: center; padding: 20px;">
                        <div class="loading" style="text-align: center;">
                            <div class="spinner-border text-light" role="status"></div>
                            <p style="margin-top: 10px;">Loading vehicles...</p>
                        </div>
                    </div>
                    <!-- Contenedor para los vehículos -->
                    <div id="coupon-alert" class="coupon_alert" style="display: none;">
                        <i class="fa-solid fa-bell"></i> 
                        Way to go! Your travel dates qualify for a <span id="coupon-amount"></span>
                        <span id="coupon-type"></span> discount if you book today. Promo code: <strong id="promo-code"></strong>
                    </div>
                    <div id="vehicles-container" class="row align-items-stretch"></div>
                    <!-- Contenedor para errores -->
                    <div id="vehicles-errors" class="alert alert-danger mt-3" style="display: none;"></div>
                    <!-- Footer con el botón "Back" -->
                    <hr width="100%" class="mt-5">
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary secondary-lighter2 px-4 mt-2" id="vehicles-back-button">
                            <i class="fa-solid fa-chevron-left"></i> Back
                        </button>
                    </div>
                </div>
                <div class="tab-pane fade" id="addons" role="tabpanel">
                    <!-- Spinner para la carga de addons -->
                    <div id="addons-loading-spinner" style="display: none; text-align: center; padding: 20px;">
                        <div class="loading" style="text-align: center;">
                            <div class="spinner-border text-light" role="status"></div>
                            <p style="margin-top: 10px;">Loading products...</p>
                        </div>
                    </div>
                    <!-- Contenedor para los addons -->
                    <div id="addons-container" class="row align-items-stretch"></div>
                    <!-- Contenedor para errores -->
                    <div id="addons-errors" class="alert alert-danger mt-3" style="display: none;"></div>
                    <!-- Footer con botones "Back" y "Next" -->
                    <hr width="100%" class="mt-5">
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary secondary-lighter px-4 mt-2" id="addons-back-button">
                            <i class="fa-solid fa-chevron-left"></i> Back
                        </button>
                        <button type="button" class="btn btn-primary px-4 mt-2" id="addons-next-button">
                            Next <i class="fa-solid fa-chevron-right"></i>
                        </button>
                    </div>
                </div>
                <!-- Client Tab -->
                <div class="tab-pane fade" id="client" role="tabpanel">

                    <!-- Form for client details -->
                    <form id="client-form">
                        <!-- Client Information Fields -->
                        <div class="row mb-3">
                            <div class="col-md-6">
                                <label for="client-fname" class="form-label">First Name</label>
                                <input type="text" class="form-control" id="client-fname" placeholder="E.g. Steven">
                            </div>
                            <div class="col-md-6">
                                <label for="client-lname" class="form-label">Last Name</label>
                                <input type="text" class="form-control" id="client-lname" placeholder="E.g. Martens Williams">
                            </div>
                        </div>
                        <!-- Client Contact Fields -->
                        <div class="row mb-3">
                            <div class="col-md-6">
                                <label for="client-email" class="form-label">Email Address</label>
                                <input type="email" class="form-control" id="client-email" placeholder="E.g. email@domain.com">
                            </div>
                            <div class="col-md-6">
                                <label for="client-phone" class="form-label">Phone Number</label>
                                <input type="tel" class="form-control" id="client-phone" placeholder="E.g. +1 332 117 2234">
                            </div>
                        </div>

                        <!-- Flight Details Section (Hidden Initially) -->
                        <div id="flight-details" style="display: none;">
                            <!-- Flight Details Fields will be added dynamically -->
                        </div>

                        <!-- Payment Fields -->
                        <div id="payment-fields" style="display: none;">
                            <!-- Stripe Elements will be mounted here -->
                            <div class="row mb-3">
                                <div class="col-md-6">
                                    <label class="form-label">Card Number</label>
                                    <div id="card-number-element" class="form-control"></div>
                                </div>
                                <div class="col-md-3">
                                    <label class="form-label">Expiry Date</label>
                                    <div id="card-expiry-element" class="form-control"></div>
                                </div>
                                <div class="col-md-3">
                                    <label class="form-label">CVC</label>
                                    <div id="card-cvc-element" class="form-control"></div>
                                </div>
                            </div>
                        </div>

                        <!-- Payment Information Warning -->
                        <div class="alert alert-warning card-message mt-4" role="alert">
                            <div class="d-flex align-items-center">
                                <div class="pe-4" style="border-right: 1px solid rgb(234, 222, 183);">
                                    <i class="fa-brands fa-cc-visa" style="font-size: 24px;"></i><br>
                                    <i class="fa-brands fa-cc-mastercard" style="font-size: 24px;"></i>
                                </div>
                                <div class="ms-3">
                                    <h6 class="alert-heading">Payment Information</h6>
                                    <p>Please notice we only accept <strong>VISA</strong> and <strong>MasterCard</strong> credit cards.</p>
                                </div>
                            </div>
                        </div>

                        <!-- Special Requests Field -->
                        <div class="mb-3">
                            <label for="special-requests" class="form-label">Special requests or needs</label>
                            <textarea class="form-control" id="special-requests" rows="3"></textarea>
                        </div>

                        <!-- Promo Code Field -->
                        <div class="row pt-2">
                            <div class="col-md-4">
                                <label for="promoCode" class="form-label">Promo code</label>
                                <input type="text" class="form-control" id="promoCode">
                            </div>
                            <div class="col-md-2 d-flex align-items-end">
                                <button type="button" class="btn btn-secondary w-100 btn-coupon" id="apply-coupon-button">
                                    Apply
                                    <span id="coupon-spinner" class="spinner-border spinner-border-sm mx-2" role="status" aria-hidden="true" style="display:none;"></span>
                                </button>
                            </div>
                            <p style="color:#b53333" id="coupon-error"></p>
                            <p style="color:rgb(97, 157, 92);" id="coupon-success"></p>
                        </div>

                        <!-- Error Display -->
                        <div id="client-errors" class="alert alert-danger mt-3" style="display: none;"></div>

                        <!-- Buttons -->
                        <div class="modal-footer">
                            <button type="button" class="btn btn-secondary secondary-lighter" id="client-back-button">
                                <i class="fa-solid fa-chevron-left"></i> Back
                            </button>
                            <button type="submit" class="btn btn-primary" id="client-submit-button">
                                Pay reservation <i class="fa-solid fa-chevron-right"></i>
                            </button>
                        </div>
                    </form>
                </div>
                <div class="tab-pane fade" id="confirm" role="tabpanel">
                    <div id="confirmation-container" class="container mt-3 p-5"></div>
                </div>
            </div>
        </div>
    </div>';
}
add_shortcode('traveldesk_transportation', 'traveldesk_transportation_shortcode');


// Incluir Bootstrap
function enqueue_bootstrap() {
    wp_enqueue_style('bootstrap-css', 'https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css');
    wp_enqueue_script('bootstrap-js', 'https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js', array('jquery'), null, true);
}
add_action('wp_enqueue_scripts', 'enqueue_bootstrap');

// Encolar Flatpickr CSS y JS
wp_enqueue_style('flatpickr-css', 'https://cdn.jsdelivr.net/npm/flatpickr/dist/flatpickr.min.css');
wp_enqueue_script('flatpickr-js', 'https://cdn.jsdelivr.net/npm/flatpickr', array(), null, true);

function enqueue_font_awesome() {
    wp_enqueue_style('font-awesome', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css');
}
add_action('wp_enqueue_scripts', 'enqueue_font_awesome');

